@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -22,31 +22,25 @@ package org.italiangrid.voms.error;
  *
  */
 public enum VOMSValidationErrorCode {
-	
-	// Temporal validity
-	acNotValidAtCurrentTime,
-	
-	// LSC signature checks
-	lscFileNotFound,
-	emptyAcCertsExtension,
-	lscDescriptionDoesntMatchAcCert,
-	invalidAcCert,
-	acCertFailsSignatureVerification,
-	
-	// Local AA cert signature checks
-	aaCertNotFound,
-	invalidAaCert,
-	aaCertFailsSignatureVerification,
-	
-	// Holder checks
-	acHolderDoesntMatchCertChain,
-	
-	// Targets checks
-	localhostDoesntMatchAcTarget,
-	
-	// CAnL errors
-	canlError,
-	
-	// Other
-	other;
+
+  // Temporal validity
+  acNotValidAtCurrentTime,
+
+  // LSC signature checks
+  lscFileNotFound, emptyAcCertsExtension, lscDescriptionDoesntMatchAcCert, invalidAcCert, acCertFailsSignatureVerification,
+
+  // Local AA cert signature checks
+  aaCertNotFound, invalidAaCert, aaCertFailsSignatureVerification,
+
+  // Holder checks
+  acHolderDoesntMatchCertChain,
+
+  // Targets checks
+  localhostDoesntMatchAcTarget,
+
+  // CAnL errors
+  canlError,
+
+  // Other
+  other;
 }
