@@ -1,5 +1,5 @@
 /**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2012.
+ * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,18 +27,23 @@ import java.util.concurrent.atomic.AtomicInteger;
  */
 public class VOMSNamedThreadFactory implements ThreadFactory {
 
-	private static final AtomicInteger created = new AtomicInteger();
-	private static final String poolBaseName = "voms-thread";
+  private static final AtomicInteger created = new AtomicInteger();
+  private static final String poolBaseName = "voms-thread";
 
-	private UncaughtExceptionHandler handler;
-	public VOMSNamedThreadFactory(UncaughtExceptionHandler h) {
-		this.handler = h;
-	}
-	
-	public VOMSNamedThreadFactory(){
-		
-	}
-	public Thread newThread(Runnable r) {
-		return new VOMSThread(r, poolBaseName+"-"+created.incrementAndGet(), handler);
-	}
+  private UncaughtExceptionHandler handler;
+
+  public VOMSNamedThreadFactory(UncaughtExceptionHandler h) {
+
+    this.handler = h;
+  }
+
+  public VOMSNamedThreadFactory() {
+
+  }
+
+  public Thread newThread(Runnable r) {
+
+    return new VOMSThread(r, poolBaseName + "-" + created.incrementAndGet(),
+      handler);
+  }
 }
